-- Read the docs: https://www.lunarvim.org/docs/configuration
-- Example configs: https://github.com/LunarVim/starter.lvim
-- Video Tutorials: https://www.youtube.com/watch?v=sFA9kX-Ud_c&list=PLhoH5vyxr6QqGu0i7tt_XoVK9v-KvZ3m6
-- Forum: https://www.reddit.com/r/lunarvim/
-- Discord: https://discord.com/invite/Xb9B4Ny

require("user.c")

lvim.colorscheme = "catppuccin-frappe"
vim.opt.rnu = false -- relative numbers
vim.opt.cb = "unnamedplus"
vim.opt.nf = "alpha,octal,hex,bin,unsigned"
vim.opt.si = true
vim.opt.backup = false
lvim.builtin.nvimtree.active = false -- NOTE: using neo-tree
lvim.builtin.indentlines.active = true

vim.opt.ts = 2
vim.opt.sw = 2
vim.opt.et = true

lvim.keys.normal_mode["<A-e>"] = ":NeoTreeFocusToggle<CR>"
lvim.keys.normal_mode["<C-h>"] = ":BufferLineCyclePrev<CR>"
lvim.keys.normal_mode["<C-l>"] = ":BufferLineCycleNext<CR>"
lvim.builtin.which_key.mappings["r"] = {
  ":RnvimrToggle<CR>", "Rnvimr"
}

lvim.format_on_save = false
vim.diagnostic.config({ virtual_text = true })

lvim.builtin.treesitter.highlight.enable = true

-- auto install treesitter parsers
lvim.builtin.treesitter.ensure_installed = { "cpp", "c" }

-- Additional Plugins
table.insert(lvim.plugins, {
  "p00f/clangd_extensions.nvim",
	"catppuccin/nvim",
	"nyoom-engineering/oxocarbon.nvim",
	"rose-pine/neovim",
	{
		"nvim-neo-tree/neo-tree.nvim",
		branch = "v2.x",
		dependencies = {
			"nvim-lua/plenary.nvim",
			"nvim-tree/nvim-web-devicons",
			"MunifTanjim/nui.nvim",
		},
		config = function()
			require("neo-tree").setup({
				close_if_last_window = true,
				window = {
					width = 30,
				},
				buffers = {
					follow_current_file = true,
				},
				filesystem = {
					follow_current_file = true,
					filtered_items = {
						hide_dotfiles = false,
						hide_gitignored = false,
						hide_by_name = {
							"node_modules"
						},
						never_show = {
							".DS_Store",
							"thumbs.db"
						},
					},
				},
			})
		end
	},
	-- "lervag/vimtex",
	--  "kdheepak/cmp-latex-symbols",
	--  "KeitaNakamura/tex-conceal.vim",
	"SirVer/ultisnips",
	{
		"ggandor/leap.nvim",
		name = "leap",
		config = function()
			require("leap").add_default_mappings()
		end,
	},
	{
		"mrjones2014/nvim-ts-rainbow",
	},
	{
		"nacro90/numb.nvim",
		event = "BufRead",
		config = function()
			require("numb").setup {
				show_numbers = true, -- Enable 'number' for the window while peeking
				show_cursorline = true, -- Enable 'cursorline' for the window while peeking
			}
		end,
	},
	{
		"kevinhwang91/rnvimr",
		cmd = "RnvimrToggle",
		config = function()
			vim.g.rnvimr_draw_border = 1
			vim.g.rnvimr_pick_enable = 1
			vim.g.rnvimr_bw_enable = 1
		end,
	},
})

vim.list_extend(lvim.lsp.automatic_configuration.skipped_servers, { "clangd" })
